pub struct TopBlocks {
pub mc_block: BlockIdShort,
pub shard_heights: ShardHeights,
}Expand description
Stores last blocks for each workchain and shard.
Fields
mc_block: BlockIdShortshard_heights: ShardHeightsImplementations
Sourceimpl TopBlocks
impl TopBlocks
Sourcepub fn from_mc_block(mc_block_data: &BlockStuff) -> Result<Self>
pub fn from_mc_block(mc_block_data: &BlockStuff) -> Result<Self>
Extracts last blocks for each workchain and shard from the given masterchain block.
pub fn shard_heights(&self) -> &ShardHeights
Sourcepub fn contains(&self, block_id: &BlockId) -> bool
pub fn contains(&self, block_id: &BlockId) -> bool
Checks whether the given block is equal to or greater than the last block for the given shard.
Sourcepub fn contains_shard_seqno(&self, shard_ident: &ShardIdent, seqno: u32) -> bool
pub fn contains_shard_seqno(&self, shard_ident: &ShardIdent, seqno: u32) -> bool
Checks whether the given pair of ShardIdent and seqno
is equal to or greater than the last block for the given shard.
NOTE: Specified shard could be split or merged
Sourcepub fn short_ids(&self) -> TopBlocksShortIdsIter<'_> ⓘ
pub fn short_ids(&self) -> TopBlocksShortIdsIter<'_> ⓘ
Returns an iterator over the short ids of the latest blocks.