pub struct ShardStateStuff { /* private fields */ }Expand description
Parsed shard state.
Implementations
Sourceimpl ShardStateStuff
impl ShardStateStuff
pub fn construct_split_root(left: Cell, right: Cell) -> Result<Cell>
pub fn from_root( block_id: &BlockId, root: Cell, handle: RefMcStateHandle, ) -> Result<Self>
pub fn from_state_and_root( block_id: &BlockId, shard_state: Box<ShardStateUnsplit>, root: Cell, handle: RefMcStateHandle, ) -> Result<Self>
pub fn block_id(&self) -> &BlockId
pub fn state(&self) -> &ShardStateUnsplit
pub fn state_extra(&self) -> Result<&McStateExtra>
pub fn ref_mc_state_handle(&self) -> &RefMcStateHandle
pub fn root_cell(&self) -> &Cell
pub fn shards(&self) -> Result<&ShardHashes>
pub fn config_params(&self) -> Result<&BlockchainConfig>
pub fn get_gen_chain_time(&self) -> u64
pub fn get_top_shards(&self) -> Result<Vec<ShardIdent>>
Sourcepub fn track_usage(
&self,
usage_mode: UsageTreeMode,
) -> Result<(UsageTree, Self)>
pub fn track_usage( &self, usage_mode: UsageTreeMode, ) -> Result<(UsageTree, Self)>
Creates a derived state which tracks access to cells data and references.
Sourcepub fn par_make_next_state(
&self,
next_block_id: &BlockId,
merkle_update: &MerkleUpdate,
split_at_depth: Option<u8>,
) -> Result<Self>
pub fn par_make_next_state( &self, next_block_id: &BlockId, merkle_update: &MerkleUpdate, split_at_depth: Option<u8>, ) -> Result<Self>
Applies merkle update of the specified block and preserves
the tracker from the initial state.
NOTE: Call from inside rayon.